# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from whop.whopclient.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from whop.whopclient.model.ban_license_by_key_response import BanLicenseByKeyResponse
from whop.whopclient.model.checkout_log import CheckoutLog
from whop.whopclient.model.confirm_product_request import ConfirmProductRequest
from whop.whopclient.model.confirm_product_response import ConfirmProductResponse
from whop.whopclient.model.create_checkout_log_request import CreateCheckoutLogRequest
from whop.whopclient.model.create_checkout_log_response import CreateCheckoutLogResponse
from whop.whopclient.model.create_link_request import CreateLinkRequest
from whop.whopclient.model.create_link_response import CreateLinkResponse
from whop.whopclient.model.create_product_request import CreateProductRequest
from whop.whopclient.model.create_product_response import CreateProductResponse
from whop.whopclient.model.create_product_response_product import CreateProductResponseProduct
from whop.whopclient.model.error_response import ErrorResponse
from whop.whopclient.model.get_checkout_logs_response import GetCheckoutLogsResponse
from whop.whopclient.model.get_license_by_key_response import GetLicenseByKeyResponse
from whop.whopclient.model.get_licenses_response import GetLicensesResponse
from whop.whopclient.model.get_links_response import GetLinksResponse
from whop.whopclient.model.get_product_by_id_response import GetProductByIdResponse
from whop.whopclient.model.get_products_response import GetProductsResponse
from whop.whopclient.model.license import License
from whop.whopclient.model.license_discord import LicenseDiscord
from whop.whopclient.model.license_plan import LicensePlan
from whop.whopclient.model.license_twitter import LicenseTwitter
from whop.whopclient.model.link import Link
from whop.whopclient.model.product import Product
from whop.whopclient.model.reset_license_by_key_response import ResetLicenseByKeyResponse
from whop.whopclient.model.send_push_notification_request import SendPushNotificationRequest
from whop.whopclient.model.send_push_notification_response import SendPushNotificationResponse
from whop.whopclient.model.update_license_by_key_request import UpdateLicenseByKeyRequest
from whop.whopclient.model.update_license_by_key_response import UpdateLicenseByKeyResponse
from whop.whopclient.model.validate_license_by_key_request import ValidateLicenseByKeyRequest
from whop.whopclient.model.validate_license_by_key_response import ValidateLicenseByKeyResponse



import whop.whopclient as whopclient
from whop.whopclient.api import (
    checkout_logs_api,
    products_api,
    notifications_api,
    links_api,
    licenses_api,
)


from whop.whopclient.model.create_product_request import CreateProductRequest
from whop.whopclient.model.confirm_product_request import ConfirmProductRequest
from whop.whopclient.model.send_push_notification_request import (
    SendPushNotificationRequest,
)

from whop.whopclient.model.create_link_request import CreateLinkRequest
from whop.whopclient.model.validate_license_by_key_request import (
    ValidateLicenseByKeyRequest,
)
from whop.whopclient.model.update_license_by_key_request import (
    UpdateLicenseByKeyRequest,
)


from whop.whopclient.model.create_checkout_log_request import CreateCheckoutLogRequest
from whop.whopclient.model.error_response import ErrorResponse
from whop.static.internal_utils import _remove_none_values
from typing import Optional
import json


class Whop:
    def __init__(self, bearer=None, client_id=None):
        api_key = {}
        if client_id:
            api_key["ClientID"] = client_id
        self.api_client = whopclient.ApiClient(
            whopclient.Configuration(access_token=bearer, api_key=api_key)
        )

    def get_products(self, **kwargs):
        # Fetch All Products
        try:
            client = whopclient.api.products_api.ProductsApi(self.api_client)

            resp = client.get_products(**kwargs)
            return resp
        except Exception as e:
            err_resp = json.loads(e.body)
            return ErrorResponse(
                success=err_resp.get("success", None),
                message=err_resp.get("message", None),
                errors=err_resp.get("errors", None),
            )

    def get_product_by_id(self, id: int, **kwargs):
        # Fetch Product
        try:
            client = whopclient.api.products_api.ProductsApi(self.api_client)

            resp = client.get_product_by_id(id, **kwargs)
            return resp
        except Exception as e:
            err_resp = json.loads(e.body)
            return ErrorResponse(
                success=err_resp.get("success", None),
                message=err_resp.get("message", None),
                errors=err_resp.get("errors", None),
            )

    def create_product(
        self,
        title: Optional[str] = None,
        transferable: Optional[bool] = None,
        billing_period: Optional[int] = None,
        custom_trial_period: Optional[int] = None,
        license_type: Optional[str] = None,
        price: Optional[float] = None,
        stock: Optional[int] = None,
        cancel_action: Optional[str] = None,
        currency: Optional[str] = None,
        expiration_days: Optional[int] = None,
        initial_price: Optional[float] = None,
        **kwargs
    ):
        # Create Product
        try:
            client = whopclient.api.products_api.ProductsApi(self.api_client)
            body_kwargs = {
                "title": title,
                "transferable": transferable,
                "billing_period": billing_period,
                "custom_trial_period": custom_trial_period,
                "license_type": license_type,
                "price": price,
                "stock": stock,
                "cancel_action": cancel_action,
                "currency": currency,
                "expiration_days": expiration_days,
                "initial_price": initial_price,
            }

            body_kwargs = _remove_none_values(body_kwargs)
            req = CreateProductRequest(**body_kwargs)

            resp = client.create_product(create_product_request=req, **kwargs)
            return resp
        except Exception as e:
            err_resp = json.loads(e.body)
            return ErrorResponse(
                success=err_resp.get("success", None),
                message=err_resp.get("message", None),
                errors=err_resp.get("errors", None),
            )

    def confirm_product(
        self,
        cancel_action: Optional[str] = None,
        initial_price: Optional[float] = None,
        license_type: Optional[str] = None,
        price: Optional[float] = None,
        stock: Optional[int] = None,
        billing_period: Optional[int] = None,
        currency: Optional[str] = None,
        custom_trial_period: Optional[int] = None,
        expiration_days: Optional[int] = None,
        title: Optional[str] = None,
        transferable: Optional[bool] = None,
        **kwargs
    ):
        # Product Creation Confirmation
        try:
            client = whopclient.api.products_api.ProductsApi(self.api_client)
            body_kwargs = {
                "cancel_action": cancel_action,
                "initial_price": initial_price,
                "license_type": license_type,
                "price": price,
                "stock": stock,
                "billing_period": billing_period,
                "currency": currency,
                "custom_trial_period": custom_trial_period,
                "expiration_days": expiration_days,
                "title": title,
                "transferable": transferable,
            }

            body_kwargs = _remove_none_values(body_kwargs)
            req = ConfirmProductRequest(**body_kwargs)

            resp = client.confirm_product(confirm_product_request=req, **kwargs)
            return resp
        except Exception as e:
            err_resp = json.loads(e.body)
            return ErrorResponse(
                success=err_resp.get("success", None),
                message=err_resp.get("message", None),
                errors=err_resp.get("errors", None),
            )

    def send_push_notification(
        self,
        body: Optional[str] = None,
        link: Optional[str] = None,
        title: Optional[str] = None,
        **kwargs
    ):
        # Send a push notification
        try:
            client = whopclient.api.notifications_api.NotificationsApi(self.api_client)
            body_kwargs = {
                "body": body,
                "link": link,
                "title": title,
            }

            body_kwargs = _remove_none_values(body_kwargs)
            req = SendPushNotificationRequest(**body_kwargs)

            resp = client.send_push_notification(
                send_push_notification_request=req, **kwargs
            )
            return resp
        except Exception as e:
            err_resp = json.loads(e.body)
            return ErrorResponse(
                success=err_resp.get("success", None),
                message=err_resp.get("message", None),
                errors=err_resp.get("errors", None),
            )

    def get_links(self, **kwargs):
        # Fetch Links
        try:
            client = whopclient.api.links_api.LinksApi(self.api_client)

            resp = client.get_links(**kwargs)
            return resp
        except Exception as e:
            err_resp = json.loads(e.body)
            return ErrorResponse(
                success=err_resp.get("success", None),
                message=err_resp.get("message", None),
                errors=err_resp.get("errors", None),
            )

    def create_link(
        self,
        discord_ids: Optional[list] = None,
        password: Optional[str] = None,
        product_id: Optional[int] = None,
        stock: Optional[int] = None,
        **kwargs
    ):
        # Create Password Protected Link
        try:
            client = whopclient.api.links_api.LinksApi(self.api_client)
            body_kwargs = {
                "discord_ids": discord_ids,
                "password": password,
                "product_id": product_id,
                "stock": stock,
            }

            body_kwargs = _remove_none_values(body_kwargs)
            req = CreateLinkRequest(**body_kwargs)

            resp = client.create_link(create_link_request=req, **kwargs)
            return resp
        except Exception as e:
            err_resp = json.loads(e.body)
            return ErrorResponse(
                success=err_resp.get("success", None),
                message=err_resp.get("message", None),
                errors=err_resp.get("errors", None),
            )

    def validate_license_by_key(
        self, key: str, metadata: Optional[dict] = None, **kwargs
    ):
        # Validate Key
        try:
            client = whopclient.api.licenses_api.LicensesApi(self.api_client)
            body_kwargs = {
                "metadata": metadata,
            }

            body_kwargs = _remove_none_values(body_kwargs)
            req = ValidateLicenseByKeyRequest(**body_kwargs)

            resp = client.validate_license_by_key(
                key, validate_license_by_key_request=req, **kwargs
            )
            return resp
        except Exception as e:
            err_resp = json.loads(e.body)
            return ErrorResponse(
                success=err_resp.get("success", None),
                message=err_resp.get("message", None),
                errors=err_resp.get("errors", None),
            )

    def update_license_by_key(
        self, key: str, metadata: Optional[dict] = None, **kwargs
    ):
        # Update License
        try:
            client = whopclient.api.licenses_api.LicensesApi(self.api_client)
            body_kwargs = {
                "metadata": metadata,
            }

            body_kwargs = _remove_none_values(body_kwargs)
            req = UpdateLicenseByKeyRequest(**body_kwargs)

            resp = client.update_license_by_key(
                key, update_license_by_key_request=req, **kwargs
            )
            return resp
        except Exception as e:
            err_resp = json.loads(e.body)
            return ErrorResponse(
                success=err_resp.get("success", None),
                message=err_resp.get("message", None),
                errors=err_resp.get("errors", None),
            )

    def reset_license_by_key(self, key: str, **kwargs):
        # Reset License
        try:
            client = whopclient.api.licenses_api.LicensesApi(self.api_client)

            resp = client.reset_license_by_key(key, **kwargs)
            return resp
        except Exception as e:
            err_resp = json.loads(e.body)
            return ErrorResponse(
                success=err_resp.get("success", None),
                message=err_resp.get("message", None),
                errors=err_resp.get("errors", None),
            )

    def get_licenses(
        self,
        discord_account_id: Optional[str] = None,
        page: Optional[int] = None,
        start: Optional[str] = None,
        end: Optional[str] = None,
        **kwargs
    ):
        # Fetch All Licenses
        try:
            client = whopclient.api.licenses_api.LicensesApi(self.api_client)
            kwargs.update(
                {
                    "discord_account_id": discord_account_id,
                    "page": page,
                    "start": start,
                    "end": end,
                }
            )

            kwargs = _remove_none_values(kwargs)

            resp = client.get_licenses(**kwargs)
            return resp
        except Exception as e:
            err_resp = json.loads(e.body)
            return ErrorResponse(
                success=err_resp.get("success", None),
                message=err_resp.get("message", None),
                errors=err_resp.get("errors", None),
            )

    def get_license_by_key(self, key: str, **kwargs):
        # Fetch License
        try:
            client = whopclient.api.licenses_api.LicensesApi(self.api_client)

            resp = client.get_license_by_key(key, **kwargs)
            return resp
        except Exception as e:
            err_resp = json.loads(e.body)
            return ErrorResponse(
                success=err_resp.get("success", None),
                message=err_resp.get("message", None),
                errors=err_resp.get("errors", None),
            )

    def ban_license_by_key(self, key: str, **kwargs):
        # Ban License
        try:
            client = whopclient.api.licenses_api.LicensesApi(self.api_client)

            resp = client.ban_license_by_key(key, **kwargs)
            return resp
        except Exception as e:
            err_resp = json.loads(e.body)
            return ErrorResponse(
                success=err_resp.get("success", None),
                message=err_resp.get("message", None),
                errors=err_resp.get("errors", None),
            )

    def get_checkout_logs(
        self, key: Optional[str] = None, status: Optional[str] = None, **kwargs
    ):
        # Fetch Checkout Logs
        try:
            client = whopclient.api.checkout_logs_api.CheckoutLogsApi(self.api_client)
            kwargs.update(
                {
                    "key": key,
                    "status": status,
                }
            )

            kwargs = _remove_none_values(kwargs)

            resp = client.get_checkout_logs(**kwargs)
            return resp
        except Exception as e:
            err_resp = json.loads(e.body)
            return ErrorResponse(
                success=err_resp.get("success", None),
                message=err_resp.get("message", None),
                errors=err_resp.get("errors", None),
            )

    def create_checkout_log(
        self,
        key: Optional[str] = None,
        price: Optional[float] = None,
        product_name: Optional[str] = None,
        size: Optional[int] = None,
        status: Optional[str] = None,
        website: Optional[str] = None,
        image_url: Optional[str] = None,
        **kwargs
    ):
        # Add Checkout Log
        try:
            client = whopclient.api.checkout_logs_api.CheckoutLogsApi(self.api_client)
            body_kwargs = {
                "key": key,
                "price": price,
                "product_name": product_name,
                "size": size,
                "status": status,
                "website": website,
                "image_url": image_url,
            }

            body_kwargs = _remove_none_values(body_kwargs)
            req = CreateCheckoutLogRequest(**body_kwargs)

            resp = client.create_checkout_log(create_checkout_log_request=req, **kwargs)
            return resp
        except Exception as e:
            err_resp = json.loads(e.body)
            return ErrorResponse(
                success=err_resp.get("success", None),
                message=err_resp.get("message", None),
                errors=err_resp.get("errors", None),
            )



# flake8: noqa

"""
    Whop API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.10
    Contact: support@whop.com
    Generated by: https://openapi-generator.tech
"""


__version__ = "1.0.0"

# import ApiClient
from whop.whopclient.api_client import ApiClient

# import Configuration
from whop.whopclient.configuration import Configuration

# import exceptions
from whop.whopclient.exceptions import OpenApiException
from whop.whopclient.exceptions import ApiAttributeError
from whop.whopclient.exceptions import ApiTypeError
from whop.whopclient.exceptions import ApiValueError
from whop.whopclient.exceptions import ApiKeyError
from whop.whopclient.exceptions import ApiException



from setuptools import setup, find_packages

setup(
    name='whop',
    version='4.1',
    license='MIT',
    author="Whop",
    author_email='support@whop.com',
    packages=find_packages('src'),
    package_dir={'': 'src'},
    url='https://github.com/whopio/whop-python-sdk',
    keywords='whop',
    install_requires=[
        'python_dateutil >= 2.5.3',
        'setuptools >= 21.0.0',
        'urllib3 >= 1.25.3',
    ]
)



"""
    Whop API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.10
    Contact: support@whop.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from whop.whopclient.api_client import ApiClient, Endpoint as _Endpoint
from whop.whopclient.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from whop.whopclient.model.ban_license_by_key_response import BanLicenseByKeyResponse
from whop.whopclient.model.error_response import ErrorResponse
from whop.whopclient.model.get_license_by_key_response import GetLicenseByKeyResponse
from whop.whopclient.model.get_licenses_response import GetLicensesResponse
from whop.whopclient.model.reset_license_by_key_response import ResetLicenseByKeyResponse
from whop.whopclient.model.update_license_by_key_request import UpdateLicenseByKeyRequest
from whop.whopclient.model.update_license_by_key_response import UpdateLicenseByKeyResponse
from whop.whopclient.model.validate_license_by_key_request import ValidateLicenseByKeyRequest
from whop.whopclient.model.validate_license_by_key_response import ValidateLicenseByKeyResponse


class LicensesApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.ban_license_by_key_endpoint = _Endpoint(
            settings={
                'response_type': (BanLicenseByKeyResponse,),
                'auth': [
                    'Bearer'
                ],
                'endpoint_path': '/v1/licenses/{key}/ban',
                'operation_id': 'ban_license_by_key',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'key',
                ],
                'required': [
                    'key',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'key':
                        (str,),
                },
                'attribute_map': {
                    'key': 'key',
                },
                'location_map': {
                    'key': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_license_by_key_endpoint = _Endpoint(
            settings={
                'response_type': (GetLicenseByKeyResponse,),
                'auth': [
                    'Bearer',
                    'ClientID'
                ],
                'endpoint_path': '/v1/licenses/{key}',
                'operation_id': 'get_license_by_key',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'key',
                ],
                'required': [
                    'key',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'key':
                        (str,),
                },
                'attribute_map': {
                    'key': 'key',
                },
                'location_map': {
                    'key': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_licenses_endpoint = _Endpoint(
            settings={
                'response_type': (GetLicensesResponse,),
                'auth': [
                    'Bearer'
                ],
                'endpoint_path': '/v1/licenses',
                'operation_id': 'get_licenses',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'discord_account_id',
                    'page',
                    'start',
                    'end',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'discord_account_id':
                        (str,),
                    'page':
                        (int,),
                    'start':
                        (str,),
                    'end':
                        (str,),
                },
                'attribute_map': {
                    'discord_account_id': 'discord_account_id',
                    'page': 'page',
                    'start': 'start',
                    'end': 'end',
                },
                'location_map': {
                    'discord_account_id': 'query',
                    'page': 'query',
                    'start': 'query',
                    'end': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.reset_license_by_key_endpoint = _Endpoint(
            settings={
                'response_type': (ResetLicenseByKeyResponse,),
                'auth': [
                    'Bearer',
                    'ClientID'
                ],
                'endpoint_path': '/v1/licenses/{key}/reset',
                'operation_id': 'reset_license_by_key',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'key',
                ],
                'required': [
                    'key',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'key':
                        (str,),
                },
                'attribute_map': {
                    'key': 'key',
                },
                'location_map': {
                    'key': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.update_license_by_key_endpoint = _Endpoint(
            settings={
                'response_type': (UpdateLicenseByKeyResponse,),
                'auth': [
                    'Bearer',
                    'ClientID'
                ],
                'endpoint_path': '/v1/licenses/{key}',
                'operation_id': 'update_license_by_key',
                'http_method': 'PATCH',
                'servers': None,
            },
            params_map={
                'all': [
                    'key',
                    'update_license_by_key_request',
                ],
                'required': [
                    'key',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'key':
                        (str,),
                    'update_license_by_key_request':
                        (UpdateLicenseByKeyRequest,),
                },
                'attribute_map': {
                    'key': 'key',
                },
                'location_map': {
                    'key': 'path',
                    'update_license_by_key_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.validate_license_by_key_endpoint = _Endpoint(
            settings={
                'response_type': (ValidateLicenseByKeyResponse,),
                'auth': [
                    'Bearer',
                    'ClientID'
                ],
                'endpoint_path': '/v1/licenses/{key}/validate',
                'operation_id': 'validate_license_by_key',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'key',
                    'validate_license_by_key_request',
                ],
                'required': [
                    'key',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'key':
                        (str,),
                    'validate_license_by_key_request':
                        (ValidateLicenseByKeyRequest,),
                },
                'attribute_map': {
                    'key': 'key',
                },
                'location_map': {
                    'key': 'path',
                    'validate_license_by_key_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )

    def ban_license_by_key(
        self,
        key,
        **kwargs
    ):
        """Ban License  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.ban_license_by_key(key, async_req=True)
        >>> result = thread.get()

        Args:
            key (str): Key of the license you wish to ban.

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            BanLicenseByKeyResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['key'] = \
            key
        return self.ban_license_by_key_endpoint.call_with_http_info(**kwargs)

    def get_license_by_key(
        self,
        key,
        **kwargs
    ):
        """Fetch License  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_license_by_key(key, async_req=True)
        >>> result = thread.get()

        Args:
            key (str): Key of the license you wish to fetch.

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            GetLicenseByKeyResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['key'] = \
            key
        return self.get_license_by_key_endpoint.call_with_http_info(**kwargs)

    def get_licenses(
        self,
        **kwargs
    ):
        """Fetch All Licenses  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_licenses(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            discord_account_id (str): ID of the Discord account for which you want to fetch licenses.. [optional]
            page (int): Page number of license data to fetch.. [optional]
            start (str): Start date of license creation. Date should be in the format YYYY-MM-DD.. [optional]
            end (str): End date of license creation. Date should be in the format YYYY-MM-DD.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            GetLicensesResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        return self.get_licenses_endpoint.call_with_http_info(**kwargs)

    def reset_license_by_key(
        self,
        key,
        **kwargs
    ):
        """Reset License  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.reset_license_by_key(key, async_req=True)
        >>> result = thread.get()

        Args:
            key (str): Key of the license you wish to reset.

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            ResetLicenseByKeyResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['key'] = \
            key
        return self.reset_license_by_key_endpoint.call_with_http_info(**kwargs)

    def update_license_by_key(
        self,
        key,
        **kwargs
    ):
        """Update License  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_license_by_key(key, async_req=True)
        >>> result = thread.get()

        Args:
            key (str): Key of the license you wish to update.

        Keyword Args:
            update_license_by_key_request (UpdateLicenseByKeyRequest): Details of license key metadata.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            UpdateLicenseByKeyResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['key'] = \
            key
        return self.update_license_by_key_endpoint.call_with_http_info(**kwargs)

    def validate_license_by_key(
        self,
        key,
        **kwargs
    ):
        """Validate Key  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.validate_license_by_key(key, async_req=True)
        >>> result = thread.get()

        Args:
            key (str): Key of the license you wish to validate.

        Keyword Args:
            validate_license_by_key_request (ValidateLicenseByKeyRequest): Details of license key metadata.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            ValidateLicenseByKeyResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['key'] = \
            key
        return self.validate_license_by_key_endpoint.call_with_http_info(**kwargs)

